@@ -8,7 +8,7 @@ from socket import timeout as TimeoutError
 import libevdev
 
 from .codes import codes, types
-from .common import get_monitor, remap, wacom_width, wacom_height, log_event
+from .common import get_monitor, remap, wacom_max_x, wacom_max_y, log_event
 
 logging.basicConfig(format='%(message)s')
 log = logging.getLogger('remouse')
@@ -46,9 +46,9 @@ def create_local_device():
 
     inputs = (
         # touch inputs
-        (libevdev.EV_ABS.ABS_MT_POSITION_X,  0,    767,   2531),
-        (libevdev.EV_ABS.ABS_MT_POSITION_Y,  0,    1023,  2531),
-        (libevdev.EV_ABS.ABS_MT_PRESSURE,    0,    255,   None),
+        (libevdev.EV_ABS.ABS_MT_POSITION_X,  0,    20967,   100),
+        (libevdev.EV_ABS.ABS_MT_POSITION_Y,  0,    15725,  100),
+        (libevdev.EV_ABS.ABS_MT_PRESSURE,    0,    4095,   None),
         (libevdev.EV_ABS.ABS_MT_TOUCH_MAJOR, 0,    255,   None),
         (libevdev.EV_ABS.ABS_MT_TOUCH_MINOR, 0,    255,   None),
         (libevdev.EV_ABS.ABS_MT_ORIENTATION, -127, 127,   None),
@@ -57,12 +57,12 @@ def create_local_device():
         (libevdev.EV_ABS.ABS_MT_TRACKING_ID, 0,    65535, None),
 
         # pen inputs
-        (libevdev.EV_ABS.ABS_X,        0,     20967,  2531), # cyttps5_mt driver
-        (libevdev.EV_ABS.ABS_Y,        0,     15725,  2531), # cyttsp5_mt
+        (libevdev.EV_ABS.ABS_X,        0,     20967,  100), # cyttps5_mt driver
+        (libevdev.EV_ABS.ABS_Y,        0,     15725,  100), # cyttsp5_mt
         (libevdev.EV_ABS.ABS_PRESSURE, 0,     4095,   None),
         (libevdev.EV_ABS.ABS_DISTANCE, 0,     255,    None),
-        (libevdev.EV_ABS.ABS_TILT_X,   -9000, 9000,   None),
-        (libevdev.EV_ABS.ABS_TILT_Y,   -9000, 9000,   None)
+        (libevdev.EV_ABS.ABS_TILT_X,   -6400, 6400,   6400),
+        (libevdev.EV_ABS.ABS_TILT_Y,   -6400, 6400,   6400)
     )
 
     for code, minimum, maximum, resolution in inputs:
@@ -91,7 +91,7 @@ def read_tablet(rm_inputs, *, orientation, monitor_num, region, threshold, mode)
     local_device = create_local_device()
     log.debug("Created virtual input device '{}'".format(local_device.devnode))
 
-    monitor = get_monitor(region, monitor_num, orientation)
+    monitor, (tot_width, tot_height) = get_monitor(region, monitor_num, orientation)
 
     pending_events = []
 
@@ -111,28 +111,33 @@ def read_tablet(rm_inputs, *, orientation, monitor_num, region, threshold, mode)
         # intercept EV_ABS events and modify coordinates
         if types[e_type] == 'EV_ABS':
             # handle x direction
-            if codes[e_type][e_code] == 'ABS_Y':
+            if codes[e_type][e_code] == 'ABS_X':
                 x = e_value
 
             # handle y direction
-            if codes[e_type][e_code] == 'ABS_X':
+            if codes[e_type][e_code] == 'ABS_Y':
                 y = e_value
 
+            # map to screen coordinates so that region/monitor/orientation options are applied
             mapped_x, mapped_y = remap(
                 x, y,
-                wacom_width, wacom_height,
+                wacom_max_x, wacom_max_y,
                 monitor.width, monitor.height,
                 mode, orientation
             )
 
-            # FIXME - something wrong with remapping
-            # handle x direction
-            # if codes[e_type][e_code] == 'ABS_Y':
-            #     e_value = int(mapped_x)
+            mapped_x += monitor.x
+            mapped_y += monitor.y
 
-            # # handle y direction
-            # if codes[e_type][e_code] == 'ABS_X':
-            #     e_value = int(mapped_y)
+            # map back to wacom coordinates to reinsert into event
+            mapped_x = mapped_x * wacom_max_x / tot_width
+            mapped_y = mapped_y * wacom_max_y / tot_height
+
+            # reinsert modified values into evdev event
+            if codes[e_type][e_code] == 'ABS_X':
+                e_value = int(mapped_x)
+            if codes[e_type][e_code] == 'ABS_Y':
+                e_value = int(mapped_y)
 
         # pass events directly to libevdev
         e_bit = libevdev.evbit(e_type, e_code)
